PyXMake Developer Guide: PyXMake.Build.Make.Py2X Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | List of all members
PyXMake.Build.Make.Py2X Class Reference

Base class for all Py2X (for now only f2py) build events. More...

Inheritance diagram for PyXMake.Build.Make.Py2X:

## Public Member Functions
def | __init__ (self, args, kwargs)
Public Member Functions inherited from PyXMake.Build.Make.Make
def | __init__ (self, BuildID, Srcs, scratch=os.getcwd(), msvsc='vs2015', stype='Fortran', verbose=0, args, kwargs)
def | __getstate__ (self)
def | __setstate__ (self, _dict)
def | AddIncludePath (self, includes)
def | AddDependencyPath (self, dependencies)
def | UseLibraries (self, libs)
def | SourcePath (self, path)
def | OutputPath (self, path, files="")
def | Environment (self, path, script="ifortvars.bat")
def | Preprocessing
def | Build (self, cmdstring)
def | Postprocessing (self, cmdstring='')
def | create (self)

## Public Attributes
| MakeObjectKind
| String identifier of current instance. More...
| no_static_mkl
| Define whether Intel's MKL should be statically or dynamically linked. More...
| no_append_arch
| Define whether the architecture shall be appended to the build name. More...
| incremental
| Define if the input should be compiled exactly as provided. More...
| path2exe
| Absolute system path to Python executable. More...
| exe
| The executable command used in the main build event. More...
| buildname
| Temporary build name of current job. More...
| architecture
| libs
| temps
| Tuple of temporary files deleted after job completion. More...
Public Attributes inherited from PyXMake.Build.Make.Make
| buildid
| Base string of build object. More...
| srcs
| Source file or folders.
| stype
| Source file type.
| verbose
| Level of verbosity of the current build object. More...
| scrtdir
| Current scratch directory.
| srcdir
| Default search directory for source files. More...
| outdir
| Default search directory for output. More...
| intelpath
| Path to Intel Fortran Compiler (read from Paths.log). More...
| temps
| Tuple of data to be removed after job completion. More...
| incdirs
| List of include directories. More...
| libdirs
| List of library directories. More...
| libs
| List of actual libraries (by name) used during linking. More...
| copyfiles
| List of files to be copied to the output directory after finish. More...
| setarch
| Define the architecture for the build directly by using the keyword argument "arch". More...
| architecture
| Processor architecture.
| iniCompiler
| Executable batch script (including absolute system path) to set up the Intel Fortran Compiler. More...
| msvsc
| Default version of Microsoft visual studio used by the Intel Fortran Compiler. More...
| postcmd
| Post build command. More...
| buildname
| precmd
| Command executed during pre-build event. More...
| compargs
| Command line arguments passed in by the user. More...
| makecmd
| Command executed during build event. More...

## Detailed Description

Base class for all Py2X (for now only f2py) build events.

    Inherited class to build projects using Py2X.

Inherited from Make.

Definition at line 930 of file Make.py.

## Constructor & Destructor Documentation

## ◆ __init__()

def PyXMake.Build.Make.Py2X.__init__ | ( |  | self,
|  |  | args,
|  |  | kwargs
| ) |  |

    Initialization of Py2X class object.

    @note Currently uses f2py - but should be build with Py2X (DLR) in the future

Definition at line 934 of file Make.py.

## Member Data Documentation

## ◆ buildname

PyXMake.Build.Make.Py2X.buildname

Temporary build name of current job.

Definition at line 975 of file Make.py.

## ◆ exe

PyXMake.Build.Make.Py2X.exe

The executable command used in the main build event.

Definition at line 960 of file Make.py.

## ◆ incremental

PyXMake.Build.Make.Py2X.incremental

Define if the input should be compiled exactly as provided.

Defaults to False, meaning that merging & pre-processing utilities will be carried out.

Definition at line 954 of file Make.py.

## ◆ MakeObjectKind

PyXMake.Build.Make.Py2X.MakeObjectKind

String identifier of current instance.

Definition at line 942 of file Make.py.

## ◆ no_append_arch

PyXMake.Build.Make.Py2X.no_append_arch

Define whether the architecture shall be appended to the build name.

Defaults to False, meaning that the architecture is appended.

Definition at line 950 of file Make.py.

## ◆ no_static_mkl

PyXMake.Build.Make.Py2X.no_static_mkl

Define whether Intel's MKL should be statically or dynamically linked.

Defaults to True, meaning that Intel's MKL has to be provided by the operating system.

Definition at line 946 of file Make.py.

## ◆ path2exe

PyXMake.Build.Make.Py2X.path2exe

Absolute system path to Python executable.

Definition at line 958 of file Make.py.

## ◆ temps

PyXMake.Build.Make.Py2X.temps

Tuple of temporary files deleted after job completion.

Has already stored custom variable declaration mapping file used by f2py.

Definition at line 1010 of file Make.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/Build/Make.py